@@ -1,33 +1,56 @@
-/*jshint node:true */
+/* eslint-env node */
+
 module.exports = function ( grunt ) {
-	grunt.loadNpmTasks( 'grunt-contrib-copy' );
-	grunt.loadNpmTasks( 'grunt-contrib-jshint' );
-	grunt.loadNpmTasks( 'grunt-stylelint' );
-	grunt.loadNpmTasks( 'grunt-contrib-watch' );
-	grunt.loadNpmTasks( 'grunt-banana-checker' );
-	grunt.loadNpmTasks( 'grunt-jscs' );
-	grunt.loadNpmTasks( 'grunt-jsonlint' );
-	grunt.loadNpmTasks( 'grunt-karma' );
 
 	var wgServer = process.env.MW_SERVER,
 		wgScriptPath = process.env.MW_SCRIPT_PATH,
+		WebdriverIOconfigFile,
 		karmaProxy = {};
 
-	karmaProxy[ wgScriptPath ] = wgServer + wgScriptPath;
+	grunt.loadNpmTasks( 'grunt-banana-checker' );
+	grunt.loadNpmTasks( 'grunt-contrib-copy' );
+	grunt.loadNpmTasks( 'grunt-contrib-watch' );
+	grunt.loadNpmTasks( 'grunt-eslint' );
+	grunt.loadNpmTasks( 'grunt-jsonlint' );
+	grunt.loadNpmTasks( 'grunt-karma' );
+	grunt.loadNpmTasks( 'grunt-stylelint' );
+	grunt.loadNpmTasks( 'grunt-webdriver' );
+
+	karmaProxy[ wgScriptPath ] = {
+		target: wgServer + wgScriptPath,
+		changeOrigin: true
+	};
+
+	if ( process.env.JENKINS_HOME ) {
+		WebdriverIOconfigFile = './tests/selenium/wdio.conf.jenkins.js';
+	} else {
+		WebdriverIOconfigFile = './tests/selenium/wdio.conf.js';
+	}
 
 	grunt.initConfig( {
-		jshint: {
-			options: {
-				jshintrc: true
-			},
-			all: '.'
-		},
-		jscs: {
-			all: '.'
+		eslint: {
+			all: [
+				'**/*.js',
+				'!docs/**',
+				'!node_modules/**',
+				'!resources/lib/**',
+				'!resources/src/jquery.tipsy/**',
+				'!resources/src/jquery/jquery.farbtastic.js',
+				'!resources/src/mediawiki.libs/**',
+				// Third-party code of PHPUnit coverage report
+				'!tests/coverage/**',
+				'!vendor/**',
+				// Explicitly say "**/*.js" here in case of symlinks
+				'!extensions/**/*.js',
+				'!skins/**/*.js',
+				// Skip functions aren't even parseable
+				'!resources/src/dom-level2-skip.js',
+				'!resources/src/es5-skip.js',
+				'!resources/src/mediawiki.hidpi-skip.js'
+			]
 		},
 		jsonlint: {
 			all: [
-				'.jscsrc',
 				'**/*.json',
 				'!{docs/js,extensions,node_modules,skins,vendor}/**'
 			]
@@ -44,11 +67,11 @@ module.exports = function ( grunt ) {
 			options: {
 				syntax: 'less'
 			},
-			src: '{resources/src/*,mw-config/**}/*.{css,less}'
+			src: '{resources/src,mw-config}/**/*.{css,less}'
 		},
 		watch: {
 			files: [
-				'.{stylelintrc,jscsrc,jshintignore,jshintrc}',
+				'.{stylelintrc,eslintrc.json}',
 				'**/*',
 				'!{docs,extensions,node_modules,skins,vendor}/**'
 			],
@@ -65,15 +88,21 @@ module.exports = function ( grunt ) {
 				} ],
 				logLevel: 'DEBUG',
 				frameworks: [ 'qunit' ],
-				reporters: [ 'progress' ],
+				reporters: [ 'mocha' ],
 				singleRun: true,
 				autoWatch: false,
 				// Some tests in extensions don't yield for more than the default 10s (T89075)
-				browserNoActivityTimeout: 60 * 1000
+				browserNoActivityTimeout: 60 * 1000,
+				// Karma requires Same-Origin (or CORS) by default since v1.1.1
+				// for better stacktraces. But we load the first request from wgServer
+				crossOriginAttribute: false
 			},
 			main: {
 				browsers: [ 'Chrome' ]
 			},
+			chromium: {
+				browsers: [ 'Chromium' ]
+			},
 			more: {
 				browsers: [ 'Chrome', 'Firefox' ]
 			}
@@ -87,7 +116,15 @@ module.exports = function ( grunt ) {
 					return require( 'path' ).join( dest, src.replace( 'resources/', '' ) );
 				}
 			}
+		},
+
+		// Configure WebdriverIO task
+		webdriver: {
+			test: {
+				configFile: WebdriverIOconfigFile
+			}
 		}
+
 	} );
 
 	grunt.registerTask( 'assert-mw-env', function () {
@@ -103,7 +140,7 @@ module.exports = function ( grunt ) {
 		return !!( process.env.MW_SERVER && process.env.MW_SCRIPT_PATH );
 	} );
 
-	grunt.registerTask( 'lint', [ 'jshint', 'jscs', 'jsonlint', 'banana', 'stylelint' ] );
+	grunt.registerTask( 'lint', [ 'eslint', 'banana', 'stylelint' ] );
 	grunt.registerTask( 'qunit', [ 'assert-mw-env', 'karma:main' ] );
 
 	grunt.registerTask( 'test', [ 'lint' ] );
