@@ -4,20 +4,18 @@
  * @package SyntaxHighlight_GeSHi
  */
 
-/*jshint node:true */
+/* eslint-env node */
 module.exports = function ( grunt ) {
+	var conf = grunt.file.readJSON( 'extension.json' );
+
 	grunt.loadNpmTasks( 'grunt-banana-checker' );
-	grunt.loadNpmTasks( 'grunt-contrib-jshint' );
 	grunt.loadNpmTasks( 'grunt-contrib-watch' );
-	grunt.loadNpmTasks( 'grunt-jscs' );
+	grunt.loadNpmTasks( 'grunt-eslint' );
 	grunt.loadNpmTasks( 'grunt-jsonlint' );
 	grunt.loadNpmTasks( 'grunt-stylelint' );
 
 	grunt.initConfig( {
-		jshint: {
-			options: {
-				jshintrc: true
-			},
+		eslint: {
 			all: [
 				'*.js',
 				'modules/**/*.js'
@@ -30,9 +28,6 @@ module.exports = function ( grunt ) {
 				'modules/**/*.json'
 			]
 		},
-		jscs: {
-			all: '<%= jshint.all %>'
-		},
 		stylelint: {
 			all: [
 				'**/*.css',
@@ -41,22 +36,17 @@ module.exports = function ( grunt ) {
 				'!node_modules/**'
 			]
 		},
-		banana: {
-			options: {
-				disallowDuplicateTranslations: false
-			},
-			all: 'i18n/'
-		},
+		banana: conf.MessagesDirs,
 		watch: {
 			files: [
 				'.{stylelintrc,jscsrc,jshintignore,jshintrc}',
-				'<%= jshint.all %>',
+				'<%= eslint.all %>',
 				'<%= stylelint.all %>'
 			],
 			tasks: 'test'
 		}
 	} );
 
-	grunt.registerTask( 'test', [ 'jshint', 'jsonlint', 'jscs', 'stylelint', 'banana' ] );
+	grunt.registerTask( 'test', [ 'eslint', 'jsonlint', 'stylelint', 'banana' ] );
 	grunt.registerTask( 'default', 'test' );
 };
