@@ -24,6 +24,7 @@
 namespace MediaWiki\Auth;
 
 use Config;
+use MediaWiki\MediaWikiServices;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerInterface;
 use Status;
@@ -146,7 +147,7 @@ class AuthManager implements LoggerAwareInterface {
 		if ( self::$instance === null ) {
 			self::$instance = new self(
 				\RequestContext::getMain()->getRequest(),
-				\ConfigFactory::getDefaultInstance()->makeConfig( 'main' )
+				MediaWikiServices::getInstance()->getMainConfig()
 			);
 		}
 		return self::$instance;
