@@ -20,6 +20,11 @@
  * @file
  */
 
+use Wikimedia\Rdbms\LoadBalancer;
+use Wikimedia\Rdbms\IDatabase;
+use Wikimedia\Rdbms\DBConnRef;
+use Wikimedia\Rdbms\MaintainableDBConnRef;
+
 /**
  * DB accessable external objects.
  *
@@ -33,6 +38,8 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	 * The provided URL is in the form of DB://cluster/id
 	 * or DB://cluster/id/itemid for concatened storage.
 	 *
+	 * @param string $url
+	 * @return string|bool False if missing
 	 * @see ExternalStoreMedium::fetchFromURL()
 	 */
 	public function fetchFromURL( $url ) {
@@ -56,7 +63,7 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	 *     are not represented.
 	 */
 	public function batchFetchFromURLs( array $urls ) {
-		$batched = $inverseUrlMap = array();
+		$batched = $inverseUrlMap = [];
 		foreach ( $urls as $url ) {
 			list( $cluster, $id, $itemID ) = $this->parseURL( $url );
 			$batched[$cluster][$id][] = $itemID;
@@ -64,7 +71,7 @@ class ExternalStoreDB extends ExternalStoreMedium {
 			// since we do === from the $itemID in $batched
 			$inverseUrlMap[$cluster][$id][$itemID] = $url;
 		}
-		$ret = array();
+		$ret = [];
 		foreach ( $batched as $cluster => $batchByCluster ) {
 			$res = $this->batchFetchBlobs( $cluster, $batchByCluster );
 			/** @var HistoryBlob $blob */
@@ -83,21 +90,18 @@ class ExternalStoreDB extends ExternalStoreMedium {
 		return $ret;
 	}
 
-	/**
-	 * @see ExternalStoreMedium::store()
-	 */
-	public function store( $cluster, $data ) {
-		$dbw = $this->getMaster( $cluster );
+	public function store( $location, $data ) {
+		$dbw = $this->getMaster( $location );
 		$id = $dbw->nextSequenceValue( 'blob_blob_id_seq' );
 		$dbw->insert( $this->getTable( $dbw ),
-			array( 'blob_id' => $id, 'blob_text' => $data ),
+			[ 'blob_id' => $id, 'blob_text' => $data ],
 			__METHOD__ );
 		$id = $dbw->insertId();
 		if ( !$id ) {
 			throw new MWException( __METHOD__ . ': no insert ID' );
 		}
 
-		return "DB://$cluster/$id";
+		return "DB://$location/$id";
 	}
 
 	/**
@@ -106,19 +110,17 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	 * @param string $cluster Cluster name
 	 * @return LoadBalancer
 	 */
-	function getLoadBalancer( $cluster ) {
-		$wiki = isset( $this->params['wiki'] ) ? $this->params['wiki'] : false;
-
-		return wfGetLBFactory()->getExternalLB( $cluster, $wiki );
+	private function getLoadBalancer( $cluster ) {
+		return wfGetLBFactory()->getExternalLB( $cluster );
 	}
 
 	/**
-	 * Get a slave database connection for the specified cluster
+	 * Get a replica DB connection for the specified cluster
 	 *
 	 * @param string $cluster Cluster name
-	 * @return DatabaseBase
+	 * @return DBConnRef
 	 */
-	function getSlave( $cluster ) {
+	public function getSlave( $cluster ) {
 		global $wgDefaultExternalStore;
 
 		$wiki = isset( $this->params['wiki'] ) ? $this->params['wiki'] : false;
@@ -131,7 +133,7 @@ class ExternalStoreDB extends ExternalStoreMedium {
 			wfDebug( "writable external store\n" );
 		}
 
-		$db = $lb->getConnection( DB_SLAVE, array(), $wiki );
+		$db = $lb->getConnectionRef( DB_REPLICA, [], $wiki );
 		$db->clearFlag( DBO_TRX ); // sanity
 
 		return $db;
@@ -141,13 +143,13 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	 * Get a master database connection for the specified cluster
 	 *
 	 * @param string $cluster Cluster name
-	 * @return DatabaseBase
+	 * @return MaintainableDBConnRef
 	 */
-	function getMaster( $cluster ) {
+	public function getMaster( $cluster ) {
 		$wiki = isset( $this->params['wiki'] ) ? $this->params['wiki'] : false;
 		$lb = $this->getLoadBalancer( $cluster );
 
-		$db = $lb->getConnection( DB_MASTER, array(), $wiki );
+		$db = $lb->getMaintenanceConnectionRef( DB_MASTER, [], $wiki );
 		$db->clearFlag( DBO_TRX ); // sanity
 
 		return $db;
@@ -156,10 +158,10 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	/**
 	 * Get the 'blobs' table name for this database
 	 *
-	 * @param DatabaseBase $db
+	 * @param IDatabase $db
 	 * @return string Table name ('blobs' by default)
 	 */
-	function getTable( $db ) {
+	public function getTable( $db ) {
 		$table = $db->getLBInfo( 'blobs table' );
 		if ( is_null( $table ) ) {
 			$table = 'blobs';
@@ -175,17 +177,16 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	 * @param string $cluster
 	 * @param string $id
 	 * @param string $itemID
-	 * @return mixed
-	 * @private
+	 * @return HistoryBlob|bool Returns false if missing
 	 */
-	function fetchBlob( $cluster, $id, $itemID ) {
+	private function fetchBlob( $cluster, $id, $itemID ) {
 		/**
 		 * One-step cache variable to hold base blobs; operations that
 		 * pull multiple revisions may often pull multiple times from
 		 * the same blob. By keeping the last-used one open, we avoid
 		 * redundant unserialization and decompression overhead.
 		 */
-		static $externalBlobCache = array();
+		static $externalBlobCache = [];
 
 		$cacheID = ( $itemID === false ) ? "$cluster/$id" : "$cluster/$id/";
 		if ( isset( $externalBlobCache[$cacheID] ) ) {
@@ -200,14 +201,14 @@ class ExternalStoreDB extends ExternalStoreMedium {
 
 		$dbr = $this->getSlave( $cluster );
 		$ret = $dbr->selectField( $this->getTable( $dbr ),
-			'blob_text', array( 'blob_id' => $id ), __METHOD__ );
+			'blob_text', [ 'blob_id' => $id ], __METHOD__ );
 		if ( $ret === false ) {
 			wfDebugLog( 'ExternalStoreDB',
 				"ExternalStoreDB::fetchBlob master fallback on $cacheID" );
 			// Try the master
 			$dbw = $this->getMaster( $cluster );
 			$ret = $dbw->selectField( $this->getTable( $dbw ),
-				'blob_text', array( 'blob_id' => $id ), __METHOD__ );
+				'blob_text', [ 'blob_id' => $id ], __METHOD__ );
 			if ( $ret === false ) {
 				wfDebugLog( 'ExternalStoreDB',
 					"ExternalStoreDB::fetchBlob master failed to find $cacheID" );
@@ -218,7 +219,7 @@ class ExternalStoreDB extends ExternalStoreMedium {
 			$ret = unserialize( $ret );
 		}
 
-		$externalBlobCache = array( $cacheID => $ret );
+		$externalBlobCache = [ $cacheID => $ret ];
 
 		return $ret;
 	}
@@ -231,11 +232,11 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	 * @return array A map from the blob_id's requested to their content.
 	 *   Unlocated ids are not represented
 	 */
-	function batchFetchBlobs( $cluster, array $ids ) {
+	private function batchFetchBlobs( $cluster, array $ids ) {
 		$dbr = $this->getSlave( $cluster );
 		$res = $dbr->select( $this->getTable( $dbr ),
-			array( 'blob_id', 'blob_text' ), array( 'blob_id' => array_keys( $ids ) ), __METHOD__ );
-		$ret = array();
+			[ 'blob_id', 'blob_text' ], [ 'blob_id' => array_keys( $ids ) ], __METHOD__ );
+		$ret = [];
 		if ( $res !== false ) {
 			$this->mergeBatchResult( $ret, $ids, $res );
 		}
@@ -246,8 +247,8 @@ class ExternalStoreDB extends ExternalStoreMedium {
 			// Try the master
 			$dbw = $this->getMaster( $cluster );
 			$res = $dbw->select( $this->getTable( $dbr ),
-				array( 'blob_id', 'blob_text' ),
-				array( 'blob_id' => array_keys( $ids ) ),
+				[ 'blob_id', 'blob_text' ],
+				[ 'blob_id' => array_keys( $ids ) ],
 				__METHOD__ );
 			if ( $res === false ) {
 				wfDebugLog( __CLASS__, __METHOD__ . " master failed on '$cluster'" );
@@ -265,10 +266,10 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	}
 
 	/**
-	 * Helper function for self::batchFetchBlobs for merging master/slave results
+	 * Helper function for self::batchFetchBlobs for merging master/replica DB results
 	 * @param array &$ret Current self::batchFetchBlobs return value
 	 * @param array &$ids Map from blob_id to requested itemIDs
-	 * @param mixed $res DB result from DatabaseBase::select
+	 * @param mixed $res DB result from Database::select
 	 */
 	private function mergeBatchResult( array &$ret, array &$ids, $res ) {
 		foreach ( $res as $row ) {
@@ -292,10 +293,10 @@ class ExternalStoreDB extends ExternalStoreMedium {
 	protected function parseURL( $url ) {
 		$path = explode( '/', $url );
 
-		return array(
+		return [
 			$path[2], // cluster
 			$path[3], // id
 			isset( $path[4] ) ? $path[4] : false // itemID
-		);
+		];
 	}
 }
