@@ -21,7 +21,9 @@
  * @ingroup FileAbstraction
  */
 
-use \MediaWiki\Logger\LoggerFactory;
+use MediaWiki\Logger\LoggerFactory;
+use Wikimedia\Rdbms\Database;
+use Wikimedia\Rdbms\IDatabase;
 
 /**
  * Class to represent a local file in the wiki's own database
@@ -174,7 +176,7 @@ class LocalFile extends File {
 	 * @return bool|LocalFile
 	 */
 	static function newFromKey( $sha1, $repo, $timestamp = false ) {
-		$dbr = $repo->getSlaveDB();
+		$dbr = $repo->getReplicaDB();
 
 		$conds = [ 'img_sha1' => $sha1 ];
 		if ( $timestamp ) {
@@ -240,6 +242,15 @@ class LocalFile extends File {
 		return $this->repo->getSharedCacheKey( 'file', sha1( $this->getName() ) );
 	}
 
+	/**
+	 * @param WANObjectCache $cache
+	 * @return string[]
+	 * @since 1.28
+	 */
+	public function getMutableCacheKeys( WANObjectCache $cache ) {
+		return [ $this->getCacheKey() ];
+	}
+
 	/**
 	 * Try to load file metadata from memcached, falling back to the database
 	 */
@@ -259,7 +270,7 @@ class LocalFile extends File {
 			$key,
 			$cache::TTL_WEEK,
 			function ( $oldValue, &$ttl, array &$setOpts ) use ( $cache ) {
-				$setOpts += Database::getCacheSetOptions( $this->repo->getSlaveDB() );
+				$setOpts += Database::getCacheSetOptions( $this->repo->getReplicaDB() );
 
 				$this->loadFromDB( self::READ_NORMAL );
 
@@ -382,7 +393,7 @@ class LocalFile extends File {
 	 * @param int $flags
 	 */
 	function loadFromDB( $flags = 0 ) {
-		$fname = get_class( $this ) . '::' . __FUNCTION__;
+		$fname = static::class . '::' . __FUNCTION__;
 
 		# Unconditionally set loaded=true, we don't want the accessors constantly rechecking
 		$this->dataLoaded = true;
@@ -390,7 +401,7 @@ class LocalFile extends File {
 
 		$dbr = ( $flags & self::READ_LATEST )
 			? $this->repo->getMasterDB()
-			: $this->repo->getSlaveDB();
+			: $this->repo->getReplicaDB();
 
 		$row = $dbr->selectRow( 'image', $this->getCacheFields( 'img_' ),
 			[ 'img_name' => $this->getName() ], $fname );
@@ -407,12 +418,12 @@ class LocalFile extends File {
 	 * This covers fields that are sometimes not cached.
 	 */
 	protected function loadExtraFromDB() {
-		$fname = get_class( $this ) . '::' . __FUNCTION__;
+		$fname = static::class . '::' . __FUNCTION__;
 
 		# Unconditionally set loaded=true, we don't want the accessors constantly rechecking
 		$this->extraDataLoaded = true;
 
-		$fieldMap = $this->loadFieldsWithTimestamp( $this->repo->getSlaveDB(), $fname );
+		$fieldMap = $this->loadFieldsWithTimestamp( $this->repo->getReplicaDB(), $fname );
 		if ( !$fieldMap ) {
 			$fieldMap = $this->loadFieldsWithTimestamp( $this->repo->getMasterDB(), $fname );
 		}
@@ -490,7 +501,7 @@ class LocalFile extends File {
 
 		$decoded['timestamp'] = wfTimestamp( TS_MW, $decoded['timestamp'] );
 
-		$decoded['metadata'] = $this->repo->getSlaveDB()->decodeBlob( $decoded['metadata'] );
+		$decoded['metadata'] = $this->repo->getReplicaDB()->decodeBlob( $decoded['metadata'] );
 
 		if ( empty( $decoded['major_mime'] ) ) {
 			$decoded['mime'] = 'unknown/unknown';
@@ -882,7 +893,7 @@ class LocalFile extends File {
 				$files[] = $file;
 			}
 		} catch ( FileBackendError $e ) {
-		} // suppress (bug 54674)
+		} // suppress (T56674)
 
 		return $files;
 	}
@@ -1037,7 +1048,7 @@ class LocalFile extends File {
 	 * @return OldLocalFile[]
 	 */
 	function getHistory( $limit = null, $start = null, $end = null, $inc = true ) {
-		$dbr = $this->repo->getSlaveDB();
+		$dbr = $this->repo->getReplicaDB();
 		$tables = [ 'oldimage' ];
 		$fields = OldLocalFile::selectFields();
 		$conds = $opts = $join_conds = [];
@@ -1091,9 +1102,9 @@ class LocalFile extends File {
 	 */
 	public function nextHistoryLine() {
 		# Polymorphic function name to distinguish foreign and local fetches
-		$fname = get_class( $this ) . '::' . __FUNCTION__;
+		$fname = static::class . '::' . __FUNCTION__;
 
-		$dbr = $this->repo->getSlaveDB();
+		$dbr = $this->repo->getReplicaDB();
 
 		if ( $this->historyLine == 0 ) { // called for the first time, return line from cur
 			$this->historyRes = $dbr->select( 'image',
@@ -1344,7 +1355,7 @@ class LocalFile extends File {
 				}
 			}
 
-			# (bug 34993) Note: $oldver can be empty here, if the previous
+			# (T36993) Note: $oldver can be empty here, if the previous
 			# version of the file was broken. Allow registration of the new
 			# version to continue anyway, because that's better than having
 			# an image that's not fixable by user operations.
@@ -1574,7 +1585,7 @@ class LocalFile extends File {
 
 	/**
 	 * Move or copy a file to its public location. If a file exists at the
-	 * destination, move it to an archive. Returns a FileRepoStatus object with
+	 * destination, move it to an archive. Returns a Status object with
 	 * the archive name in the "value" member on success.
 	 *
 	 * The archive name should be passed through to recordUpload for database
@@ -1592,7 +1603,7 @@ class LocalFile extends File {
 	}
 
 	/**
-	 * Move or copy a file to a specified location. Returns a FileRepoStatus
+	 * Move or copy a file to a specified location. Returns a Status
 	 * object with the archive name in the "value" member on success.
 	 *
 	 * The archive name should be passed through to recordUpload for database
@@ -1919,7 +1930,7 @@ class LocalFile extends File {
 				'page_namespace' => $this->title->getNamespace(),
 				'page_title' => $this->title->getDBkey()
 			];
-			$touched = $this->repo->getSlaveDB()->selectField( 'page', 'page_touched', $cond, __METHOD__ );
+			$touched = $this->repo->getReplicaDB()->selectField( 'page', 'page_touched', $cond, __METHOD__ );
 			$this->descriptionTouched = $touched ? wfTimestamp( TS_MW, $touched ) : false;
 		}
 
@@ -1998,7 +2009,7 @@ class LocalFile extends File {
 			$dbw = $this->repo->getMasterDB();
 			$makesTransaction = !$dbw->trxLevel();
 			$dbw->startAtomic( self::ATOMIC_SECTION_LOCK );
-			// Bug 54736: use simple lock to handle when the file does not exist.
+			// T56736: use simple lock to handle when the file does not exist.
 			// SELECT FOR UPDATE prevents changes, not other SELECTs with FOR UPDATE.
 			// Also, that would cause contention on INSERT of similarly named rows.
 			$status = $this->acquireFileLock(); // represents all versions of the file
@@ -2088,7 +2099,7 @@ class LocalFileDeleteBatch {
 	/** @var bool Whether to suppress all suppressable fields when deleting */
 	private $suppress;
 
-	/** @var FileRepoStatus */
+	/** @var Status */
 	private $status;
 
 	/** @var User */
@@ -2236,12 +2247,7 @@ class LocalFileDeleteBatch {
 
 		// Bitfields to further suppress the content
 		if ( $this->suppress ) {
-			$bitfield = 0;
-			// This should be 15...
-			$bitfield |= Revision::DELETED_TEXT;
-			$bitfield |= Revision::DELETED_COMMENT;
-			$bitfield |= Revision::DELETED_USER;
-			$bitfield |= Revision::DELETED_RESTRICTED;
+			$bitfield = Revision::SUPPRESSED_ALL;
 		} else {
 			$bitfield = 'oi_deleted';
 		}
@@ -2261,7 +2267,6 @@ class LocalFileDeleteBatch {
 					'fa_deleted_timestamp' => $encTimestamp,
 					'fa_deleted_reason' => $encReason,
 					'fa_deleted' => $this->suppress ? $bitfield : 0,
-
 					'fa_name' => 'img_name',
 					'fa_archive_name' => 'NULL',
 					'fa_size' => 'img_size',
@@ -3001,7 +3006,7 @@ class LocalFileMoveBatch {
 	}
 
 	/**
-	 * Verify the database updates and return a new FileRepoStatus indicating how
+	 * Verify the database updates and return a new Status indicating how
 	 * many rows would be updated.
 	 *
 	 * @return Status
@@ -3032,7 +3037,7 @@ class LocalFileMoveBatch {
 			$status->failCount++;
 		}
 		$status->successCount += $oldRowCount;
-		// Bug 34934: oldCount is based on files that actually exist.
+		// T36934: oldCount is based on files that actually exist.
 		// There may be more DB rows than such files, in which case $affected
 		// can be greater than $total. We use max() to avoid negatives here.
 		$status->failCount += max( 0, $this->oldCount - $oldRowCount );
@@ -3044,7 +3049,7 @@ class LocalFileMoveBatch {
 	}
 
 	/**
-	 * Do the database updates and return a new FileRepoStatus indicating how
+	 * Do the database updates and return a new Status indicating how
 	 * many rows where updated.
 	 */
 	protected function doDBUpdates() {
