@@ -20,6 +20,9 @@
  * @file
  * @ingroup Deployment
  */
+use Wikimedia\Rdbms\LBFactorySingle;
+use Wikimedia\Rdbms\Database;
+use Wikimedia\Rdbms\IDatabase;
 
 /**
  * Base class for DBMS-specific installation helper classes.
@@ -336,7 +339,6 @@ abstract class DatabaseInstaller {
 		$services->redefineService( 'DBLoadBalancerFactory', function() use ( $connection ) {
 			return LBFactorySingle::newFromConnection( $connection );
 		} );
-
 	}
 
 	/**
