@@ -21,6 +21,10 @@
  * @ingroup Deployment
  */
 
+use Wikimedia\Rdbms\Database;
+use Wikimedia\Rdbms\DatabaseSqlite;
+use Wikimedia\Rdbms\DBConnectionError;
+
 /**
  * Class for setting up the MediaWiki database using SQLLite.
  *
@@ -244,9 +248,9 @@ class SqliteInstaller extends DatabaseInstaller {
 			$sql =
 <<<EOT
 	CREATE TABLE IF NOT EXISTS objectcache (
-	  keyname BLOB NOT NULL default '' PRIMARY KEY,
-	  value BLOB,
-	  exptime TEXT
+		keyname BLOB NOT NULL default '' PRIMARY KEY,
+		value BLOB,
+		exptime TEXT
 	)
 EOT;
 			$conn->query( $sql );
