@@ -20,6 +20,14 @@
  * @file
  * @ingroup Database
  */
+namespace Wikimedia\Rdbms;
+
+use DateTime;
+use DateTimeZone;
+use MediaWiki;
+use InvalidArgumentException;
+use Exception;
+use stdClass;
 
 /**
  * Database abstraction object for MySQL.
@@ -94,7 +102,7 @@ abstract class DatabaseMysqlBase extends Database {
 	/**
 	 * @return string
 	 */
-	function getType() {
+	public function getType() {
 		return 'mysql';
 	}
 
@@ -106,7 +114,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @throws Exception|DBConnectionError
 	 * @return bool
 	 */
-	function open( $server, $user, $password, $dbName ) {
+	public function open( $server, $user, $password, $dbName ) {
 		# Close/unset connection handle
 		$this->close();
 
@@ -237,7 +245,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param ResultWrapper|resource $res
 	 * @throws DBUnexpectedError
 	 */
-	function freeResult( $res ) {
+	public function freeResult( $res ) {
 		if ( $res instanceof ResultWrapper ) {
 			$res = $res->result;
 		}
@@ -262,7 +270,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @return stdClass|bool
 	 * @throws DBUnexpectedError
 	 */
-	function fetchObject( $res ) {
+	public function fetchObject( $res ) {
 		if ( $res instanceof ResultWrapper ) {
 			$res = $res->result;
 		}
@@ -274,7 +282,7 @@ abstract class DatabaseMysqlBase extends Database {
 		// Unfortunately, mysql_fetch_object does not reset the last errno.
 		// Only check for CR_SERVER_LOST and CR_UNKNOWN_ERROR, as
 		// these are the only errors mysql_fetch_object can cause.
-		// See http://dev.mysql.com/doc/refman/5.0/en/mysql-fetch-row.html.
+		// See https://dev.mysql.com/doc/refman/5.0/en/mysql-fetch-row.html.
 		if ( $errno == 2000 || $errno == 2013 ) {
 			throw new DBUnexpectedError(
 				$this,
@@ -298,7 +306,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @return array|bool
 	 * @throws DBUnexpectedError
 	 */
-	function fetchRow( $res ) {
+	public function fetchRow( $res ) {
 		if ( $res instanceof ResultWrapper ) {
 			$res = $res->result;
 		}
@@ -310,7 +318,7 @@ abstract class DatabaseMysqlBase extends Database {
 		// Unfortunately, mysql_fetch_array does not reset the last errno.
 		// Only check for CR_SERVER_LOST and CR_UNKNOWN_ERROR, as
 		// these are the only errors mysql_fetch_array can cause.
-		// See http://dev.mysql.com/doc/refman/5.0/en/mysql-fetch-row.html.
+		// See https://dev.mysql.com/doc/refman/5.0/en/mysql-fetch-row.html.
 		if ( $errno == 2000 || $errno == 2013 ) {
 			throw new DBUnexpectedError(
 				$this,
@@ -345,7 +353,7 @@ abstract class DatabaseMysqlBase extends Database {
 		// Unfortunately, mysql_num_rows does not reset the last errno.
 		// We are not checking for any errors here, since
 		// these are no errors mysql_num_rows can cause.
-		// See http://dev.mysql.com/doc/refman/5.0/en/mysql-fetch-row.html.
+		// See https://dev.mysql.com/doc/refman/5.0/en/mysql-fetch-row.html.
 		// See https://phabricator.wikimedia.org/T44430
 		return $n;
 	}
@@ -362,7 +370,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param ResultWrapper|resource $res
 	 * @return int
 	 */
-	function numFields( $res ) {
+	public function numFields( $res ) {
 		if ( $res instanceof ResultWrapper ) {
 			$res = $res->result;
 		}
@@ -383,7 +391,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param int $n
 	 * @return string
 	 */
-	function fieldName( $res, $n ) {
+	public function fieldName( $res, $n ) {
 		if ( $res instanceof ResultWrapper ) {
 			$res = $res->result;
 		}
@@ -428,7 +436,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param int $row
 	 * @return bool
 	 */
-	function dataSeek( $res, $row ) {
+	public function dataSeek( $res, $row ) {
 		if ( $res instanceof ResultWrapper ) {
 			$res = $res->result;
 		}
@@ -448,7 +456,7 @@ abstract class DatabaseMysqlBase extends Database {
 	/**
 	 * @return string
 	 */
-	function lastError() {
+	public function lastError() {
 		if ( $this->mConn ) {
 			# Even if it's non-zero, it can still be invalid
 			MediaWiki\suppressWarnings();
@@ -482,7 +490,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $fname
 	 * @return ResultWrapper
 	 */
-	function replace( $table, $uniqueIndexes, $rows, $fname = __METHOD__ ) {
+	public function replace( $table, $uniqueIndexes, $rows, $fname = __METHOD__ ) {
 		return $this->nativeReplace( $table, $rows, $fname );
 	}
 
@@ -518,15 +526,17 @@ abstract class DatabaseMysqlBase extends Database {
 		return (int)$rows;
 	}
 
-	function tableExists( $table, $fname = __METHOD__ ) {
+	public function tableExists( $table, $fname = __METHOD__ ) {
 		$table = $this->tableName( $table, 'raw' );
 		if ( isset( $this->mSessionTempTables[$table] ) ) {
 			return true; // already known to exist and won't show in SHOW TABLES anyway
 		}
 
-		$encLike = $this->buildLike( $table );
+		// We can't use buildLike() here, because it specifies an escape character
+		// other than the backslash, which is the only one supported by SHOW TABLES
+		$encLike = $this->escapeLikeInternal( $table, '\\' );
 
-		return $this->query( "SHOW TABLES $encLike", $fname )->numRows() > 0;
+		return $this->query( "SHOW TABLES LIKE '$encLike'", $fname )->numRows() > 0;
 	}
 
 	/**
@@ -534,7 +544,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $field
 	 * @return bool|MySQLField
 	 */
-	function fieldInfo( $table, $field ) {
+	public function fieldInfo( $table, $field ) {
 		$table = $this->tableName( $table );
 		$res = $this->query( "SELECT * FROM $table LIMIT 1", __METHOD__, true );
 		if ( !$res ) {
@@ -569,10 +579,10 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $fname
 	 * @return bool|array|null False or null on failure
 	 */
-	function indexInfo( $table, $index, $fname = __METHOD__ ) {
+	public function indexInfo( $table, $index, $fname = __METHOD__ ) {
 		# SHOW INDEX works in MySQL 3.23.58, but SHOW INDEXES does not.
 		# SHOW INDEX should work for 3.x and up:
-		# http://dev.mysql.com/doc/mysql/en/SHOW_INDEX.html
+		# https://dev.mysql.com/doc/mysql/en/SHOW_INDEX.html
 		$table = $this->tableName( $table );
 		$index = $this->indexName( $index );
 
@@ -598,7 +608,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $s
 	 * @return string
 	 */
-	function strencode( $s ) {
+	public function strencode( $s ) {
 		return $this->mysqlRealEscapeString( $s );
 	}
 
@@ -638,7 +648,7 @@ abstract class DatabaseMysqlBase extends Database {
 		return strlen( $name ) && $name[0] == '`' && substr( $name, -1, 1 ) == '`';
 	}
 
-	function getLag() {
+	public function getLag() {
 		if ( $this->getLagDetectionMethod() === 'pt-heartbeat' ) {
 			return $this->getLagFromPtHeartbeat();
 		} else {
@@ -756,19 +766,25 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @see https://www.percona.com/doc/percona-toolkit/2.1/pt-heartbeat.html
 	 */
 	protected function getHeartbeatData( array $conds ) {
-		$whereSQL = $this->makeList( $conds, self::LIST_AND );
-		// Use ORDER BY for channel based queries since that field might not be UNIQUE.
-		// Note: this would use "TIMESTAMPDIFF(MICROSECOND,ts,UTC_TIMESTAMP(6))" but the
-		// percision field is not supported in MySQL <= 5.5.
-		$res = $this->query(
-			"SELECT ts FROM heartbeat.heartbeat WHERE $whereSQL ORDER BY ts DESC LIMIT 1"
-		);
-		$row = $res ? $res->fetchObject() : false;
+		// Do not bother starting implicit transactions here
+		$this->clearFlag( self::DBO_TRX, self::REMEMBER_PRIOR );
+		try {
+			$whereSQL = $this->makeList( $conds, self::LIST_AND );
+			// Use ORDER BY for channel based queries since that field might not be UNIQUE.
+			// Note: this would use "TIMESTAMPDIFF(MICROSECOND,ts,UTC_TIMESTAMP(6))" but the
+			// percision field is not supported in MySQL <= 5.5.
+			$res = $this->query(
+				"SELECT ts FROM heartbeat.heartbeat WHERE $whereSQL ORDER BY ts DESC LIMIT 1"
+			);
+			$row = $res ? $res->fetchObject() : false;
+		} finally {
+			$this->restoreFlags();
+		}
 
 		return [ $row ? $row->ts : null, microtime( true ) ];
 	}
 
-	public function getApproximateLagStatus() {
+	protected function getApproximateLagStatus() {
 		if ( $this->getLagDetectionMethod() === 'pt-heartbeat' ) {
 			// Disable caching since this is fast enough and we don't wan't
 			// to be *too* pessimistic by having both the cache TTL and the
@@ -786,7 +802,7 @@ abstract class DatabaseMysqlBase extends Database {
 		return $approxLag;
 	}
 
-	function masterPosWait( DBMasterPos $pos, $timeout ) {
+	public function masterPosWait( DBMasterPos $pos, $timeout ) {
 		if ( !( $pos instanceof MySQLMasterPos ) ) {
 			throw new InvalidArgumentException( "Position not an instance of MySQLMasterPos" );
 		}
@@ -811,7 +827,8 @@ abstract class DatabaseMysqlBase extends Database {
 
 		$row = $res ? $this->fetchRow( $res ) : false;
 		if ( !$row ) {
-			throw new DBExpectedError( $this, "Failed to query MASTER_POS_WAIT()" );
+			throw new DBExpectedError( $this,
+				"MASTER_POS_WAIT() or MASTER_GTID_WAIT() failed: {$this->lastError()}" );
 		}
 
 		// Result can be NULL (error), -1 (timeout), or 0+ per the MySQL manual
@@ -839,7 +856,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 *
 	 * @return MySQLMasterPos|bool
 	 */
-	function getReplicaPos() {
+	public function getReplicaPos() {
 		$res = $this->query( 'SHOW SLAVE STATUS', __METHOD__ );
 		$row = $this->fetchObject( $res );
 
@@ -867,7 +884,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 *
 	 * @return MySQLMasterPos|bool
 	 */
-	function getMasterPos() {
+	public function getMasterPos() {
 		$res = $this->query( 'SHOW MASTER STATUS', __METHOD__ );
 		$row = $this->fetchObject( $res );
 
@@ -1013,7 +1030,7 @@ abstract class DatabaseMysqlBase extends Database {
 
 	/**
 	 * FROM MYSQL DOCS:
-	 * http://dev.mysql.com/doc/refman/5.0/en/miscellaneous-functions.html#function_release-lock
+	 * https://dev.mysql.com/doc/refman/5.0/en/miscellaneous-functions.html#function_release-lock
 	 * @param string $lockName
 	 * @param string $method
 	 * @return bool
@@ -1034,7 +1051,7 @@ abstract class DatabaseMysqlBase extends Database {
 	}
 
 	private function makeLockName( $lockName ) {
-		// http://dev.mysql.com/doc/refman/5.7/en/miscellaneous-functions.html#function_get-lock
+		// https://dev.mysql.com/doc/refman/5.7/en/miscellaneous-functions.html#function_get-lock
 		// Newer version enforce a 64 char length limit.
 		return ( strlen( $lockName ) > 64 ) ? sha1( $lockName ) : $lockName;
 	}
@@ -1043,36 +1060,26 @@ abstract class DatabaseMysqlBase extends Database {
 		return true;
 	}
 
-	/**
-	 * @param array $read
-	 * @param array $write
-	 * @param string $method
-	 * @param bool $lowPriority
-	 * @return bool
-	 */
-	public function lockTables( $read, $write, $method, $lowPriority = true ) {
-		$items = [];
+	public function tableLocksHaveTransactionScope() {
+		return false; // tied to TCP connection
+	}
 
+	protected function doLockTables( array $read, array $write, $method ) {
+		$items = [];
 		foreach ( $write as $table ) {
-			$tbl = $this->tableName( $table ) .
-				( $lowPriority ? ' LOW_PRIORITY' : '' ) .
-				' WRITE';
-			$items[] = $tbl;
+			$items[] = $this->tableName( $table ) . ' WRITE';
 		}
 		foreach ( $read as $table ) {
 			$items[] = $this->tableName( $table ) . ' READ';
 		}
+
 		$sql = "LOCK TABLES " . implode( ',', $items );
 		$this->query( $sql, $method );
 
 		return true;
 	}
 
-	/**
-	 * @param string $method
-	 * @return bool
-	 */
-	public function unlockTables( $method ) {
+	protected function doUnlockTables( $method ) {
 		$this->query( "UNLOCK TABLES", $method );
 
 		return true;
@@ -1108,7 +1115,9 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @throws DBUnexpectedError
 	 * @return bool|ResultWrapper
 	 */
-	function deleteJoin( $delTable, $joinTable, $delVar, $joinVar, $conds, $fname = __METHOD__ ) {
+	public function deleteJoin(
+		$delTable, $joinTable, $delVar, $joinVar, $conds, $fname = __METHOD__
+	) {
 		if ( !$conds ) {
 			throw new DBUnexpectedError( $this, __METHOD__ . ' called with empty $conds' );
 		}
@@ -1162,7 +1171,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 *
 	 * @return int
 	 */
-	function getServerUptime() {
+	public function getServerUptime() {
 		$vars = $this->getMysqlStatus( 'Uptime' );
 
 		return (int)$vars['Uptime'];
@@ -1173,7 +1182,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 *
 	 * @return bool
 	 */
-	function wasDeadlock() {
+	public function wasDeadlock() {
 		return $this->lastErrno() == 1213;
 	}
 
@@ -1182,11 +1191,11 @@ abstract class DatabaseMysqlBase extends Database {
 	 *
 	 * @return bool
 	 */
-	function wasLockTimeout() {
+	public function wasLockTimeout() {
 		return $this->lastErrno() == 1205;
 	}
 
-	function wasErrorReissuable() {
+	public function wasErrorReissuable() {
 		return $this->lastErrno() == 2013 || $this->lastErrno() == 2006;
 	}
 
@@ -1195,12 +1204,12 @@ abstract class DatabaseMysqlBase extends Database {
 	 *
 	 * @return bool
 	 */
-	function wasReadOnlyError() {
+	public function wasReadOnlyError() {
 		return $this->lastErrno() == 1223 ||
 			( $this->lastErrno() == 1290 && strpos( $this->lastError(), '--read-only' ) !== false );
 	}
 
-	function wasConnectionError( $errno ) {
+	public function wasConnectionError( $errno ) {
 		return $errno == 2013 || $errno == 2006;
 	}
 
@@ -1211,7 +1220,9 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $fname
 	 * @return bool
 	 */
-	function duplicateTableStructure( $oldName, $newName, $temporary = false, $fname = __METHOD__ ) {
+	public function duplicateTableStructure(
+		$oldName, $newName, $temporary = false, $fname = __METHOD__
+	) {
 		$tmp = $temporary ? 'TEMPORARY ' : '';
 		$newName = $this->addIdentifierQuotes( $newName );
 		$oldName = $this->addIdentifierQuotes( $oldName );
@@ -1227,7 +1238,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $fname Calling function name
 	 * @return array
 	 */
-	function listTables( $prefix = null, $fname = __METHOD__ ) {
+	public function listTables( $prefix = null, $fname = __METHOD__ ) {
 		$result = $this->query( "SHOW TABLES", $fname );
 
 		$endArray = [];
@@ -1263,7 +1274,7 @@ abstract class DatabaseMysqlBase extends Database {
 	 * @param string $which
 	 * @return array
 	 */
-	function getMysqlStatus( $which = "%" ) {
+	private function getMysqlStatus( $which = "%" ) {
 		$res = $this->query( "SHOW STATUS LIKE '{$which}'" );
 		$status = [];
 
@@ -1320,5 +1331,40 @@ abstract class DatabaseMysqlBase extends Database {
 	public function isView( $name, $prefix = null ) {
 		return in_array( $name, $this->listViews( $prefix ) );
 	}
+
+	/**
+	 * Allows for index remapping in queries where this is not consistent across DBMS
+	 *
+	 * @param string $index
+	 * @return string
+	 */
+	protected function indexName( $index ) {
+		/**
+		 * When SQLite indexes were introduced in r45764, it was noted that
+		 * SQLite requires index names to be unique within the whole database,
+		 * not just within a schema. As discussed in CR r45819, to avoid the
+		 * need for a schema change on existing installations, the indexes
+		 * were implicitly mapped from the new names to the old names.
+		 *
+		 * This mapping can be removed if DB patches are introduced to alter
+		 * the relevant tables in existing installations. Note that because
+		 * this index mapping applies to table creation, even new installations
+		 * of MySQL have the old names (except for installations created during
+		 * a period where this mapping was inappropriately removed, see
+		 * T154872).
+		 */
+		$renamed = [
+			'ar_usertext_timestamp' => 'usertext_timestamp',
+			'un_user_id' => 'user_id',
+			'un_user_ip' => 'user_ip',
+		];
+
+		if ( isset( $renamed[$index] ) ) {
+			return $renamed[$index];
+		} else {
+			return $index;
+		}
+	}
 }
 
+class_alias( DatabaseMysqlBase::class, 'DatabaseMysqlBase' );
