@@ -49,7 +49,6 @@ use Wikimedia\ScopedCallback;
  * Note XMP kind of looks like rdf. They are not the same thing - XMP is
  * encoded as a specific subset of rdf. This class can read XMP. It cannot
  * read rdf.
- *
  */
 class XMPReader implements LoggerAwareInterface {
 	/** @var array XMP item configuration array */
@@ -492,7 +491,7 @@ class XMPReader implements LoggerAwareInterface {
 	 * <exif:DigitalZoomRatio>0/10</exif:DigitalZoomRatio>
 	 * and are processing the 0/10 bit.
 	 *
-	 * @param XMLParser $parser XMLParser reference to the xml parser
+	 * @param resource $parser XMLParser reference to the xml parser
 	 * @param string $data Character data
 	 * @throws RuntimeException On invalid data
 	 */
@@ -648,7 +647,7 @@ class XMPReader implements LoggerAwareInterface {
 	private function endElementNested( $elm ) {
 
 		/* cur item must be the same as $elm, unless if in MODE_STRUCT
-		   in which case it could also be rdf:Description */
+		 * in which case it could also be rdf:Description */
 		if ( $this->curItem[0] !== $elm
 			&& !( $elm === self::NS_RDF . ' Description'
 				&& $this->mode[0] === self::MODE_STRUCT )
@@ -777,7 +776,7 @@ class XMPReader implements LoggerAwareInterface {
 	 * Ignores the outer wrapping elements that are optional in
 	 * xmp and have no meaning.
 	 *
-	 * @param XMLParser $parser
+	 * @param resource $parser
 	 * @param string $elm Namespace . ' ' . element name
 	 * @throws RuntimeException
 	 */
@@ -896,7 +895,7 @@ class XMPReader implements LoggerAwareInterface {
 		if ( $elm === self::NS_RDF . ' Seq' ) {
 			array_unshift( $this->mode, self::MODE_LI );
 		} elseif ( $elm === self::NS_RDF . ' Bag' ) {
-			# bug 27105
+			# T29105
 			$this->logger->info( __METHOD__ . ' Expected an rdf:Seq, but got an rdf:Bag. Pretending'
 				. ' it is a Seq, since some buggy software is known to screw this up.' );
 			array_unshift( $this->mode, self::MODE_LI );
@@ -980,7 +979,6 @@ class XMPReader implements LoggerAwareInterface {
 	 * Called when processing the <rdf:value> or <foo:someQualifier>.
 	 *
 	 * @param string $elm Namespace and tag name separated by a space.
-	 *
 	 */
 	private function startElementModeQDesc( $elm ) {
 		if ( $elm === self::NS_RDF . ' value' ) {
@@ -1088,7 +1086,7 @@ class XMPReader implements LoggerAwareInterface {
 				}
 			} else {
 				array_unshift( $this->mode, self::MODE_IGNORE );
-				array_unshift( $this->curItem, $elm );
+				array_unshift( $this->curItem, $ns . ' ' . $tag );
 
 				return;
 			}
@@ -1190,7 +1188,7 @@ class XMPReader implements LoggerAwareInterface {
 	 * Generally just calls a helper based on what MODE we're in.
 	 * Also does some initial set up for the wrapper element
 	 *
-	 * @param XMLParser $parser
+	 * @param resource $parser
 	 * @param string $elm Namespace "<space>" element
 	 * @param array $attribs Attribute name => value
 	 * @throws RuntimeException
