@@ -98,7 +98,7 @@ class SpecialTags extends SpecialPage {
 				],
 			];
 
-			$form = new HTMLForm( $fields, $this->getContext() );
+			$form = HTMLForm::factory( 'ooui', $fields, $this->getContext() );
 			$form->setAction( $this->getPageTitle( 'create' )->getLocalURL() );
 			$form->setWrapperLegendMsg( 'tags-create-heading' );
 			$form->setHeaderText( $this->msg( 'tags-create-explanation' )->parseAsBlock() );
@@ -176,7 +176,7 @@ class SpecialTags extends SpecialPage {
 		$newRow .= Xml::tags( 'td', null, Xml::element( 'code', null, $tag ) );
 
 		$linkRenderer = $this->getLinkRenderer();
-		$disp = ChangeTags::tagDescription( $tag );
+		$disp = ChangeTags::tagDescription( $tag, $this->getContext() );
 		if ( $showEditLinks ) {
 			$disp .= ' ';
 			$editLink = $linkRenderer->makeLink(
@@ -312,7 +312,7 @@ class SpecialTags extends SpecialPage {
 				$out->parse( $status->getWikiText() ) .
 				$this->msg( 'tags-create-warnings-below' )->parseAsBlock();
 
-			$subform = new HTMLForm( $fields, $this->getContext() );
+			$subform = HTMLForm::factory( 'ooui', $fields, $this->getContext() );
 			$subform->setAction( $this->getPageTitle( 'create' )->getLocalURL() );
 			$subform->setWrapperLegendMsg( 'tags-create-heading' );
 			$subform->setHeaderText( $headerText );
@@ -377,7 +377,7 @@ class SpecialTags extends SpecialPage {
 			'required' => true,
 		];
 
-		$form = new HTMLForm( $fields, $this->getContext() );
+		$form = HTMLForm::factory( 'ooui', $fields, $this->getContext() );
 		$form->setAction( $this->getPageTitle( 'delete' )->getLocalURL() );
 		$form->tagAction = 'delete'; // custom property on HTMLForm object
 		$form->setSubmitCallback( [ $this, 'processTagForm' ] );
@@ -428,7 +428,7 @@ class SpecialTags extends SpecialPage {
 			'required' => true,
 		];
 
-		$form = new HTMLForm( $fields, $this->getContext() );
+		$form = HTMLForm::factory( 'ooui', $fields, $this->getContext() );
 		$form->setAction( $this->getPageTitle( $actionStr )->getLocalURL() );
 		$form->tagAction = $actionStr;
 		$form->setSubmitCallback( [ $this, 'processTagForm' ] );
