@@ -14,5 +14,4 @@
 $fallback = 'fr';
 
 // Remove French aliases
-$namespaceGenderAliases = array();
-
+$namespaceGenderAliases = [];
