@@ -25,6 +25,8 @@
 require_once __DIR__ . '/../includes/PHPVersionCheck.php';
 wfEntryPointCheck( 'cli' );
 
+use Wikimedia\Rdbms\DBReplicationWaitError;
+
 /**
  * @defgroup MaintenanceArchive Maintenance archives
  * @ingroup Maintenance
@@ -36,8 +38,11 @@ define( 'DO_MAINTENANCE', RUN_MAINTENANCE_IF_MAIN ); // original name, harmless
 
 $maintClass = false;
 
+use Wikimedia\Rdbms\IDatabase;
 use MediaWiki\Logger\LoggerFactory;
 use MediaWiki\MediaWikiServices;
+use Wikimedia\Rdbms\LBFactory;
+use Wikimedia\Rdbms\IMaintainableDatabase;
 
 /**
  * Abstract maintenance class for quickly writing and churning out
@@ -104,7 +109,7 @@ abstract class Maintenance {
 
 	/**
 	 * Used by getDB() / setDB()
-	 * @var Database
+	 * @var IMaintainableDatabase
 	 */
 	private $mDb = null;
 
@@ -204,7 +209,7 @@ abstract class Maintenance {
 	 * @param string $description The description of the param to show on --help
 	 * @param bool $required Is the param required?
 	 * @param bool $withArg Is an argument required with this option?
-	 * @param string $shortName Character to use as short name
+	 * @param string|bool $shortName Character to use as short name
 	 * @param bool $multiOccurrence Can this option be passed multiple times?
 	 */
 	protected function addOption( $name, $description, $required = false,
@@ -459,7 +464,6 @@ abstract class Maintenance {
 	 * Add the default parameters to the scripts
 	 */
 	protected function addDefaultParams() {
-
 		# Generic (non script dependant) options:
 
 		$this->addOption( 'help', 'Display this help message', false, false, 'h' );
@@ -499,7 +503,7 @@ abstract class Maintenance {
 	 */
 	public function getConfig() {
 		if ( $this->config === null ) {
-			$this->config = ConfigFactory::getDefaultInstance()->makeConfig( 'main' );
+			$this->config = MediaWikiServices::getInstance()->getMainConfig();
 		}
 
 		return $this->config;
@@ -546,7 +550,6 @@ abstract class Maintenance {
 				. "for this script to run: $joined. Please enable them and then try again.";
 			$this->error( $msg, 1 );
 		}
-
 	}
 
 	/**
@@ -1243,7 +1246,7 @@ abstract class Maintenance {
 	 * @param integer $db DB index (DB_REPLICA/DB_MASTER)
 	 * @param array $groups; default: empty array
 	 * @param string|bool $wiki; default: current wiki
-	 * @return Database
+	 * @return IMaintainableDatabase
 	 */
 	protected function getDB( $db, $groups = [], $wiki = false ) {
 		if ( is_null( $this->mDb ) ) {
@@ -1256,7 +1259,7 @@ abstract class Maintenance {
 	/**
 	 * Sets database object to be returned by getDB().
 	 *
-	 * @param IDatabase $db Database object to be used
+	 * @param IDatabase $db
 	 */
 	public function setDB( IDatabase $db ) {
 		$this->mDb = $db;
@@ -1318,7 +1321,7 @@ abstract class Maintenance {
 
 	/**
 	 * Lock the search index
-	 * @param Database &$db
+	 * @param IMaintainableDatabase &$db
 	 */
 	private function lockSearchindex( $db ) {
 		$write = [ 'searchindex' ];
@@ -1336,7 +1339,7 @@ abstract class Maintenance {
 
 	/**
 	 * Unlock the tables
-	 * @param Database &$db
+	 * @param IMaintainableDatabase &$db
 	 */
 	private function unlockSearchindex( $db ) {
 		$db->unlockTables( __CLASS__ . '::' . __METHOD__ );
@@ -1345,7 +1348,7 @@ abstract class Maintenance {
 	/**
 	 * Unlock and lock again
 	 * Since the lock is low-priority, queued reads will be able to complete
-	 * @param Database &$db
+	 * @param IMaintainableDatabase &$db
 	 */
 	private function relockSearchindex( $db ) {
 		$this->unlockSearchindex( $db );
@@ -1356,7 +1359,7 @@ abstract class Maintenance {
 	 * Perform a search index update with locking
 	 * @param int $maxLockTime The maximum time to keep the search index locked.
 	 * @param string $callback The function that will update the function.
-	 * @param Database $dbw
+	 * @param IMaintainableDatabase $dbw
 	 * @param array $results
 	 */
 	public function updateSearchIndex( $maxLockTime, $callback, $dbw, $results ) {
@@ -1392,7 +1395,7 @@ abstract class Maintenance {
 
 	/**
 	 * Update the searchindex table for a given pageid
-	 * @param Database $dbw A database write handle
+	 * @param IDatabase $dbw A database write handle
 	 * @param int $pageId The page ID to update.
 	 * @return null|string
 	 */
@@ -1502,6 +1505,36 @@ abstract class Maintenance {
 		return fgets( STDIN, 1024 );
 	}
 
+	/**
+	 * Get the terminal size as a two-element array where the first element
+	 * is the width (number of columns) and the second element is the height
+	 * (number of rows).
+	 *
+	 * @return array
+	 */
+	public static function getTermSize() {
+		$default = [ 80, 50 ];
+		if ( wfIsWindows() ) {
+			return $default;
+		}
+		// It's possible to get the screen size with VT-100 terminal escapes,
+		// but reading the responses is not possible without setting raw mode
+		// (unless you want to require the user to press enter), and that
+		// requires an ioctl(), which we can't do. So we have to shell out to
+		// something that can do the relevant syscalls. There are a few
+		// options. Linux and Mac OS X both have "stty size" which does the
+		// job directly.
+		$retval = false;
+		$size = wfShellExec( 'stty size', $retval );
+		if ( $retval !== 0 ) {
+			return $default;
+		}
+		if ( !preg_match( '/^(\d+) (\d+)$/', $size, $m ) ) {
+			return $default;
+		}
+		return [ intval( $m[2] ), intval( $m[1] ) ];
+	}
+
 	/**
 	 * Call this to set up the autoloader to allow classes to be used from the
 	 * tests directory.
