@@ -24,10 +24,13 @@
  * @ingroup Maintenance
  */
 
-use MediaWiki\Linker\LinkTarget;
-
 require_once __DIR__ . '/Maintenance.php';
 
+use MediaWiki\Linker\LinkTarget;
+use MediaWiki\MediaWikiServices;
+use Wikimedia\Rdbms\ResultWrapper;
+use Wikimedia\Rdbms\IMaintainableDatabase;
+
 /**
  * Maintenance script that checks for articles to fix after
  * adding/deleting namespaces.
@@ -37,7 +40,7 @@ require_once __DIR__ . '/Maintenance.php';
 class NamespaceConflictChecker extends Maintenance {
 
 	/**
-	 * @var Database
+	 * @var IMaintainableDatabase
 	 */
 	protected $db;
 
@@ -224,7 +227,7 @@ class NamespaceConflictChecker extends Maintenance {
 	 * @return array
 	 */
 	private function getInterwikiList() {
-		$result = Interwiki::getAllPrefixes();
+		$result = MediaWikiServices::getInstance()->getInterwikiLookup()->getAllPrefixes();
 		$prefixes = [];
 		foreach ( $result as $row ) {
 			$prefixes[] = $row['iw_prefix'];
@@ -570,7 +573,7 @@ class NamespaceConflictChecker extends Maintenance {
 	/**
 	 * Merge page histories
 	 *
-	 * @param integer $id The page_id
+	 * @param stdClass $row Page row
 	 * @param Title $newTitle The new title
 	 * @return bool
 	 */
