@@ -177,7 +177,7 @@
 
 	/* Static properties */
 
-	mw.widgets.datetime.DateTimeInputWidget[ 'static' ].supportsSimpleLabel = false;
+	mw.widgets.datetime.DateTimeInputWidget.static.supportsSimpleLabel = false;
 
 	/* Events */
 
@@ -390,6 +390,10 @@
 				$field = $( '<span>' )
 					.width( sz )
 					.data( 'mw-widgets-datetime-dateTimeInputWidget-placeholder', placeholder );
+				if ( spec.type !== 'static' ) {
+					$field.prop( 'tabIndex', -1 );
+					$field.on( 'focus', this.onFieldFocus.bind( this, $field ) );
+				}
 				if ( spec.type === 'static' ) {
 					$field.text( spec.value );
 				} else {
@@ -583,6 +587,7 @@
 	 * @private
 	 * @param {jQuery} $field
 	 * @param {jQuery.Event} e Key down event
+	 * @return {boolean} False to cancel the default event
 	 */
 	mw.widgets.datetime.DateTimeInputWidget.prototype.onFieldKeyDown = function ( $field, e ) {
 		var spec = $field.data( 'mw-widgets-datetime-dateTimeInputWidget-fieldSpec' );
@@ -627,6 +632,8 @@
 	 * @param {jQuery.Event} e Focus event
 	 */
 	mw.widgets.datetime.DateTimeInputWidget.prototype.onFieldFocus = function ( $field ) {
+		var spec = $field.data( 'mw-widgets-datetime-dateTimeInputWidget-fieldSpec' );
+
 		if ( !this.isDisabled() ) {
 			if ( this.getValueAsDate() === null ) {
 				this.setValue( this.formatter.getDefaultDate() );
@@ -636,7 +643,7 @@
 			}
 
 			if ( this.calendar ) {
-				this.calendar.toggle( true );
+				this.calendar.toggle( !!spec.calendarComponent );
 			}
 		}
 	};
@@ -704,6 +711,7 @@
 	 * @private
 	 * @param {jQuery} $field
 	 * @param {jQuery.Event} e Change event
+	 * @return {boolean} False to cancel the default event
 	 */
 	mw.widgets.datetime.DateTimeInputWidget.prototype.onFieldWheel = function ( $field, e ) {
 		var delta = 0,
