@@ -34,13 +34,8 @@ class MonoBookTemplate extends BaseTemplate {
 	 * Takes an associative array of data set from a SkinTemplate-based
 	 * class, and a wrapper for MediaWiki's localization database, and
 	 * outputs a formatted page.
-	 *
-	 * @access private
 	 */
-	function execute() {
-		// Suppress warnings to prevent notices about missing indexes in $this->data
-		wfSuppressWarnings();
-
+	public function execute() {
 		$this->html( 'headelement' );
 		?><div id="globalWrapper">
 		<div id="column-content">
@@ -49,7 +44,7 @@ class MonoBookTemplate extends BaseTemplate {
 				<?php
 				if ( $this->data['sitenotice'] ) {
 					?>
-					<div id="siteNotice"><?php
+					<div id="siteNotice" class="mw-body-content"><?php
 					$this->html( 'sitenotice' )
 					?></div><?php
 				}
@@ -103,13 +98,13 @@ class MonoBookTemplate extends BaseTemplate {
 					<!-- end content -->
 					<?php
 					if ( $this->data['dataAfterContent'] ) {
-						$this->html( 'dataAfterContent'
-						);
+						$this->html( 'dataAfterContent' );
 					}
 					?>
 					<div class="visualClear"></div>
 				</div>
 			</div>
+			<?php Hooks::run( 'MonoBookAfterContent' ); ?>
 		</div>
 		<div id="column-one"<?php $this->html( 'userlangattributes' ) ?>>
 			<h2><?php $this->msg( 'navigation-heading' ) ?></h2>
@@ -119,7 +114,24 @@ class MonoBookTemplate extends BaseTemplate {
 
 				<div class="pBody">
 					<ul<?php $this->html( 'userlangattributes' ) ?>>
-						<?php foreach ( $this->getPersonalTools() as $key => $item ) { ?>
+						<?php
+
+						$personalTools = $this->getPersonalTools();
+
+						if ( array_key_exists( 'uls', $personalTools ) ) {
+							echo $this->makeListItem( 'uls', $personalTools['uls'] );
+							unset( $personalTools['uls'] );
+						}
+
+						if ( !$this->getSkin()->getUser()->isLoggedIn() &&
+							User::groupHasPermission( '*', 'edit' ) ) {
+
+							echo Html::rawElement( 'li', array(
+								'id' => 'pt-anonuserpage'
+							), $this->getMsg( 'notloggedin' )->escaped() );
+						}
+
+						foreach ( $personalTools as $key => $item ) { ?>
 							<?php echo $this->makeListItem( $key, $item ); ?>
 
 						<?php
@@ -144,8 +156,8 @@ class MonoBookTemplate extends BaseTemplate {
 		</div><!-- end of the left (by default at least) column -->
 		<div class="visualClear"></div>
 		<?php
-		$validFooterIcons = $this->getFooterIcons( "icononly" );
-		$validFooterLinks = $this->getFooterLinks( "flat" ); // Additional footer links
+		$validFooterIcons = $this->getFooterIcons( 'icononly' );
+		$validFooterLinks = $this->getFooterLinks( 'flat' ); // Additional footer links
 
 		if ( count( $validFooterIcons ) + count( $validFooterLinks ) > 0 ) {
 			?>
@@ -192,7 +204,6 @@ class MonoBookTemplate extends BaseTemplate {
 		echo Html::closeElement( 'body' );
 		echo Html::closeElement( 'html' );
 		echo "\n";
-		wfRestoreWarnings();
 	} // end of execute() method
 
 	/*************************************************************************************************/
@@ -238,20 +249,20 @@ class MonoBookTemplate extends BaseTemplate {
 
 			<div id="searchBody" class="pBody">
 				<form action="<?php $this->text( 'wgScript' ) ?>" id="searchform">
-					<input type='hidden' name="title" value="<?php $this->text( 'searchtitle' ) ?>"/>
-					<?php echo $this->makeSearchInput( array( "id" => "searchInput" ) ); ?>
+					<input type="hidden" name="title" value="<?php $this->text( 'searchtitle' ) ?>"/>
+					<?php echo $this->makeSearchInput( array( 'id' => 'searchInput' ) ); ?>
 
 					<?php
 					echo $this->makeSearchButton(
-						"go",
-						array( "id" => "searchGoButton", "class" => "searchButton" )
+						'go',
+						array( 'id' => 'searchGoButton', 'class' => 'searchButton' )
 					);
 
 					if ( $this->config->get( 'UseTwoButtonsSearchForm' ) ) {
 						?>&#160;
 						<?php echo $this->makeSearchButton(
-							"fulltext",
-							array( "id" => "mw-searchButton", "class" => "searchButton" )
+							'fulltext',
+							array( 'id' => 'mw-searchButton', 'class' => 'searchButton' )
 						);
 					} else {
 						?>
@@ -270,7 +281,7 @@ class MonoBookTemplate extends BaseTemplate {
 	}
 
 	/**
-	 * Prints the cactions bar.
+	 * Prints the content actions (cactions) bar.
 	 * Shared between MonoBook and Modern
 	 */
 	function cactions() {
@@ -315,6 +326,7 @@ class MonoBookTemplate extends BaseTemplate {
 			</div>
 		</div>
 	<?php
+		Hooks::run( 'MonoBookAfterToolbox' );
 	}
 
 	/*************************************************************************************************/
@@ -326,8 +338,8 @@ class MonoBookTemplate extends BaseTemplate {
 
 				<div class="pBody">
 					<ul>
-						<?php foreach ( $this->data['language_urls'] as $key => $langlink ) { ?>
-							<?php echo $this->makeListItem( $key, $langlink ); ?>
+						<?php foreach ( $this->data['language_urls'] as $key => $langLink ) { ?>
+							<?php echo $this->makeListItem( $key, $langLink ); ?>
 
 						<?php
 }
@@ -362,7 +374,7 @@ class MonoBookTemplate extends BaseTemplate {
 		?>
 
 		<h3><?php echo htmlspecialchars( $msgObj->exists() ? $msgObj->text() : $bar ); ?></h3>
-		<div class='pBody'>
+		<div class="pBody">
 			<?php
 			if ( is_array( $cont ) ) {
 				?>
