@@ -7,6 +7,7 @@ use MediaWiki\MediaWikiServices;
 use MediaWiki\Services\DestructibleService;
 use MediaWiki\Services\SalvageableService;
 use MediaWiki\Services\ServiceDisabledException;
+use Wikimedia\Rdbms\LBFactory;
 
 /**
  * @covers MediaWiki\MediaWikiServices
@@ -70,7 +71,7 @@ class MediaWikiServicesTest extends MediaWikiTestCase {
 		$newServices = $this->newMediaWikiServices();
 		$oldServices = MediaWikiServices::forceGlobalInstance( $newServices );
 
-		$service1 = $this->getMock( SalvageableService::class );
+		$service1 = $this->createMock( SalvageableService::class );
 		$service1->expects( $this->never() )
 			->method( 'salvage' );
 
@@ -103,11 +104,11 @@ class MediaWikiServicesTest extends MediaWikiTestCase {
 		$newServices = $this->newMediaWikiServices();
 		$oldServices = MediaWikiServices::forceGlobalInstance( $newServices );
 
-		$service1 = $this->getMock( SalvageableService::class );
+		$service1 = $this->createMock( SalvageableService::class );
 		$service1->expects( $this->never() )
 			->method( 'salvage' );
 
-		$service2 = $this->getMock( SalvageableService::class );
+		$service2 = $this->createMock( SalvageableService::class );
 		$service2->expects( $this->once() )
 			->method( 'salvage' )
 			->with( $service1 );
@@ -177,11 +178,11 @@ class MediaWikiServicesTest extends MediaWikiTestCase {
 		$newServices = $this->newMediaWikiServices();
 		$oldServices = MediaWikiServices::forceGlobalInstance( $newServices );
 
-		$service1 = $this->getMock( DestructibleService::class );
+		$service1 = $this->createMock( DestructibleService::class );
 		$service1->expects( $this->once() )
 			->method( 'destroy' );
 
-		$service2 = $this->getMock( DestructibleService::class );
+		$service2 = $this->createMock( DestructibleService::class );
 		$service2->expects( $this->never() )
 			->method( 'destroy' );
 
@@ -218,7 +219,7 @@ class MediaWikiServicesTest extends MediaWikiTestCase {
 			'Test',
 			function() use ( &$serviceCounter ) {
 				$serviceCounter++;
-				$service = $this->getMock( 'MediaWiki\Services\DestructibleService' );
+				$service = $this->createMock( 'MediaWiki\Services\DestructibleService' );
 				$service->expects( $this->once() )->method( 'destroy' );
 				return $service;
 			}
@@ -247,7 +248,7 @@ class MediaWikiServicesTest extends MediaWikiTestCase {
 		$services->defineService(
 			'Test',
 			function() {
-				$service = $this->getMock( 'MediaWiki\Services\DestructibleService' );
+				$service = $this->createMock( 'MediaWiki\Services\DestructibleService' );
 				$service->expects( $this->never() )->method( 'destroy' );
 				return $service;
 			}
@@ -308,13 +309,14 @@ class MediaWikiServicesTest extends MediaWikiTestCase {
 			'SearchEngineFactory' => [ 'SearchEngineFactory', SearchEngineFactory::class ],
 			'SearchEngineConfig' => [ 'SearchEngineConfig', SearchEngineConfig::class ],
 			'SkinFactory' => [ 'SkinFactory', SkinFactory::class ],
-			'DBLoadBalancerFactory' => [ 'DBLoadBalancerFactory', 'LBFactory' ],
+			'DBLoadBalancerFactory' => [ 'DBLoadBalancerFactory', Wikimedia\Rdbms\LBFactory::class ],
 			'DBLoadBalancer' => [ 'DBLoadBalancer', 'LoadBalancer' ],
 			'WatchedItemStore' => [ 'WatchedItemStore', WatchedItemStore::class ],
 			'WatchedItemQueryService' => [ 'WatchedItemQueryService', WatchedItemQueryService::class ],
 			'CryptRand' => [ 'CryptRand', CryptRand::class ],
 			'CryptHKDF' => [ 'CryptHKDF', CryptHKDF::class ],
 			'MediaHandlerFactory' => [ 'MediaHandlerFactory', MediaHandlerFactory::class ],
+			'Parser' => [ 'Parser', Parser::class ],
 			'GenderCache' => [ 'GenderCache', GenderCache::class ],
 			'LinkCache' => [ 'LinkCache', LinkCache::class ],
 			'LinkRenderer' => [ 'LinkRenderer', LinkRenderer::class ],
