@@ -32,7 +32,6 @@ return [
 			'mediawiki.page.ready',
 			'mediawiki.page.startup',
 			'test.sinonjs',
-			'dom-level2-shim',
 		],
 		'position' => 'top',
 		'targets' => [ 'desktop', 'mobile' ],
@@ -58,7 +57,6 @@ return [
 			'tests/qunit/suites/resources/jquery/jquery.localize.test.js',
 			'tests/qunit/suites/resources/jquery/jquery.makeCollapsible.test.js',
 			'tests/qunit/suites/resources/jquery/jquery.mwExtension.test.js',
-			'tests/qunit/suites/resources/jquery/jquery.placeholder.test.js',
 			'tests/qunit/suites/resources/jquery/jquery.tabIndex.test.js',
 			'tests/qunit/suites/resources/jquery/jquery.tablesorter.test.js',
 			'tests/qunit/suites/resources/jquery/jquery.tablesorter.parsers.test.js',
@@ -76,6 +74,7 @@ return [
 			'tests/qunit/suites/resources/mediawiki/mediawiki.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.loader.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.html.test.js',
+			'tests/qunit/suites/resources/mediawiki/mediawiki.inspect.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.Title.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.toc.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.track.test.js',
@@ -93,6 +92,8 @@ return [
 			'tests/qunit/suites/resources/mediawiki.api/mediawiki.api.watch.test.js',
 			'tests/qunit/suites/resources/mediawiki.api/mediawiki.ForeignApi.test.js',
 			'tests/qunit/suites/resources/mediawiki.special/mediawiki.special.recentchanges.test.js',
+			'tests/qunit/suites/resources/mediawiki.rcfilters/dm.FiltersViewModel.test.js',
+			'tests/qunit/suites/resources/mediawiki.rcfilters/dm.FilterItem.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.language.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.cldr.test.js',
 			'tests/qunit/suites/resources/mediawiki/mediawiki.cookie.test.js',
@@ -111,7 +112,6 @@ return [
 			'jquery.localize',
 			'jquery.makeCollapsible',
 			'jquery.mwExtension',
-			'jquery.placeholder',
 			'jquery.tabIndex',
 			'jquery.tablesorter',
 			'jquery.textSelection',
@@ -136,10 +136,12 @@ return [
 			'mediawiki.util',
 			'mediawiki.viewport',
 			'mediawiki.special.recentchanges',
+			'mediawiki.rcfilters.filters.dm',
 			'mediawiki.language',
 			'mediawiki.cldr',
 			'mediawiki.cookie',
 			'mediawiki.experiments',
+			'mediawiki.inspect',
 			'test.mediawiki.qunit.testrunner',
 		],
 	]
